OC.L10N.register(
    "files_texteditor",
    {
    "Cannot read the file." : "Nemožno čítať súbor.",
    "Invalid file path supplied." : "Neplatná cesta k súboru.",
    "Cannot save file as it has been modified since opening" : "Nie je možné uložiť súbor, pretože bol od otvorenia zmenený",
    "Insufficient permissions" : "Nedostatočné oprávnenia",
    "File path not supplied" : "Nebola uvedená cesta k súboru",
    "File mtime not supplied" : "Nebol uvedený mtime súboru",
    "saving..." : "ukladám...",
    "saved!" : "uložené!",
    "failed!" : "neúspešné!",
    "Saved" : "Uložené",
    "There was a problem saving your changes. Click to resume editing." : "Vyskytol sa problém s ukladaním zmien. Kliknite pre pokračovanie v úpravách.",
    "An error occurred!" : "Vyskytla sa chyba!",
    "Text file" : "Textový súbor",
    "New text file.txt" : "Nový text file.txt"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
